==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/WebCore/dom/DocumentMediaElement.h <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(VIDEO)

#include <WebCore/Supplementable.h>
#include <wtf/CheckedPtr.h>
#include <wtf/TZoneMalloc.h>
#include <wtf/TypeCasts.h>

namespace JSC {
class JSGlobalObject;
}

namespace WebCore {

class DOMWrapperWorld;
class Document;
class JSDOMGlobalObject;
class ScriptController;

class DocumentMediaElement final : public Supplement<Document> {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(DocumentMediaElement);
public:
    static DocumentMediaElement& from(Document&);

    DocumentMediaElement(Document&);

    using JSSetupFunction = Function<bool(JSDOMGlobalObject&, JSC::JSGlobalObject&, ScriptController&, DOMWrapperWorld&)>;
    bool setupAndCallMediaControlsJS(NOESCAPE const JSSetupFunction&);

private:
    bool isDocumentMediaElement() const final { return true; }
    static ASCIILiteral supplementName();

    Document& document() const;

    DOMWrapperWorld& ensureIsolatedWorld();
    bool ensureMediaControlsScript();
    bool setupAndCallJS(NOESCAPE const JSSetupFunction&);

    CheckedRef<Document> m_document;
    RefPtr<DOMWrapperWorld> m_isolatedWorld;
    bool m_haveParsedMediaControlsScript { false };
};

}

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::DocumentMediaElement)
    static bool isType(const WebCore::SupplementBase& supplement) { return supplement.isDocumentMediaElement(); }
SPECIALIZE_TYPE_TRAITS_END()

#endif

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/dom/DocumentMediaElement.h <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(VIDEO)

#include <WebCore/Supplementable.h>
#include <wtf/CheckedPtr.h>
#include <wtf/TZoneMalloc.h>
#include <wtf/TypeCasts.h>

namespace JSC {
class JSGlobalObject;
}

namespace WebCore {

class DOMWrapperWorld;
class Document;
class JSDOMGlobalObject;
class ScriptController;

class DocumentMediaElement final : public Supplement<Document> {
    WTF_MAKE_TZONE_ALLOCATED(DocumentMediaElement);
public:
    static DocumentMediaElement& from(Document&);

    DocumentMediaElement(Document&);

    using JSSetupFunction = Function<bool(JSDOMGlobalObject&, JSC::JSGlobalObject&, ScriptController&, DOMWrapperWorld&)>;
    bool setupAndCallMediaControlsJS(NOESCAPE const JSSetupFunction&);

private:
    bool isDocumentMediaElement() const final { return true; }
    static ASCIILiteral supplementName();

    Document& document() const;

    DOMWrapperWorld& ensureIsolatedWorld();
    bool ensureMediaControlsScript();
    bool setupAndCallJS(NOESCAPE const JSSetupFunction&);

    CheckedRef<Document> m_document;
    RefPtr<DOMWrapperWorld> m_isolatedWorld;
    bool m_haveParsedMediaControlsScript { false };
};

}

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::DocumentMediaElement)
    static bool isType(const WebCore::SupplementBase& supplement) { return supplement.isDocumentMediaElement(); }
SPECIALIZE_TYPE_TRAITS_END()

#endif
